California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 73 - TERMINATION OF MINOR'S PREGNANCY. WAITING PERIOD AND PARENTAL NOTIFICATION. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280060 | PARENTS FOR PROP. 73 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280304 | NO ON 73, A PROJECT OF AMERICAN CIVIL LIBERTIES UNION OF NORTHERN CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257969 | YES ON 85, MAJOR FUNDING PROVIDED BY JIM HOLMAN, DON SEBASTIANI, AND OTHERS TO REFORM PARENTS' RIGHT TO KNOW AND CHILD PROTECTION LAWS IN CALIFORNIA. (AKA "LIFE ON THE BALLOT - PARENTS RIGHT TO KNOW") | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280288 | NO ON PROPOSITION 73: SPONSORED BY FEMINIST MAJORITY FOUNDATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280140 | CALIFORNIANS AGAINST ARNOLD'S SPECIAL INTEREST ELECTION - NO ON 73, 74, 75, 76, 77 AND 78 AND YES ON 79 AND 80, SPONSORED BY WORKING ASSETS AND BALLOT INITIATIVE STRATEGY CENTER | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1278878 | CALIFORNIA PARENTS' RIGHTS COALITION-YES ON 73-A PROJECT OF CALIFORNIA PROLIFE COUNCIL, INC. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1278872 | NO SPECIAL ELECTION - 41ST AD FIGHTING PROPOSITIONS 73, 74, 75, 76 AND 78 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280977 | ASIAN PACIFIC AMERICANS FOR AN INFORMED CALIFORNIA, SPONSORED BY THE ASIAN LAW CAUCUS, A COMMITTEE AGAINST PROPOSITIONS 73, 74, 75, 76, AND 77 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280232 | CALIFORNIANS FOR FAMILY RIGHTS, YES ON PROP. 73, SPONSORED BY CATHOLIC COMMON GOOD FOUNDATION OF CALIF., INC. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1276142 | CAMPAIGN FOR TEEN SAFETY - NO ON 85 - A PROJECT OF PLANNED PARENTHOOD AFFILIATES OF CALIFORNIA | OPPOSE